@@ -1021,5 +1021,5 @@ dataf.geneexp <- function() return(structure(list(
     3, 3, 2, 3, 3, 3, 3, 3, 1, 3, 1, 1, 3, 1, 3, 1, 3, 1, 3, 
     3, 2, 1, 3, 3, 3, 3, 1, 2, 2, 2, 2, 2, 1, 2, 2, 3, 3, 2, 
     1, 3, 1, 2, 2, 2, 3, 3, 1, 2, 1, 1, 1, 2, 2, 3, 2, 2, 2, 
-    2, 1, 2, 2, 3, 3, 3, 3, 2)))
+    2, 1, 2, 2, 3, 3, 3, 3, 2)), class = "functional")
 )
\ No newline at end of file
