@@ -16,37 +16,12 @@ DD-plot, Journal of the American Statistical Association 107(498): 737 - 753.
 #include <limits>
 #include <boost/math/special_functions/binomial.hpp>
 
-/**
-Calculates the empirical risk for two classes on the basis of given depths
-and approximates it to get continuous derivative
+#include "asa047.h"
 
-@param polynomial : Polynomial as a vector of coefficients starting with the first degree(a0 = 0 always)
-@param points : nx2 matrix of depths, where each column contains the depths against the corresponding class
-@param numClass1:  Number of points belonging to the first class
-@return polynomial as a vector of coefficients starting with the first degree (a0 = 0 always)
-
-@throws Smoothed empirical risk
-*/
-double GetEmpiricalRiskSmoothed(TPoint& polynomial, TMatrix& points, unsigned numClass1){
-	const float smoothingConstant = 100;
-	unsigned degree = polynomial.size();
-
-	double risk = 0;
-	int sign = 1;
-	for (unsigned i = 0; i < points.size(); i++){
-		if (i >= numClass1)
-			sign = -1;
-
-		double val = points[i][0];
-		double res = 0;
-		for (unsigned j = 0; j < degree; j++){
-			res += polynomial[j] * std::pow(val, j);
-		}
-		risk += 1 / (1 + exp(-smoothingConstant*(points[i][1] - res)*sign));
-	}
-
-	return risk / points.size();
-}
+#ifndef _MSC_VER
+#include <Rcpp.h>
+using namespace Rcpp;
+#endif
 
 /**
 Calculates the empirical risk for two classes on the basis of given depths
@@ -58,31 +33,32 @@ Calculates the empirical risk for two classes on the basis of given depths
 
 @throws empirical risk
 */
-double GetEmpiricalRisk(TPoint& polynomial, TMatrix& points, unsigned numClass1){
+double GetEmpiricalRisk(TPoint& polynomial, TDMatrix points, unsigned numClass1, unsigned numClass2){
 	unsigned degree = polynomial.size();
+	unsigned n = numClass1 + numClass2;
 
 	double risk = 0;
 	int sign = 1;
-	for (unsigned i = 0; i < points.size(); i++){
+	for (unsigned i = 0; i < n; i++){
 		if (i >= numClass1)
 			sign = -1;
 
 		double val = points[i][0];
 		double res = 0;
 		for (unsigned j = 0; j<degree; j++){
-			res += polynomial[j] * std::pow(val, j);
+			res += polynomial[j] * std::pow(val, j+1);
 		}
 		if ((points[i][1] - res)*sign > 0){    // for class1 depths[i,2] > res, for class 2 <
 			risk++;
 		}
 	}
 
-	return risk / points.size();
+	return risk / n;
 }
 
 /**
 Calculates the coefficients of the polynomial of a given degree
-pathing through given points an the origin
+going through given points and the origin
 
 @param degree : degree of the polynomial, should be equal the number of points
 @param points : degreex2 points for the polynomial to path through
@@ -91,7 +67,7 @@ pathing through given points an the origin
 
 @throws runtime_error in case of singularity
 */
-TPoint GetPolynomial(unsigned degree, TMatrix& points) {
+bool GetPolynomial(unsigned degree, TDMatrix points, TPoint& polynomial) {
 
 	bMatrix A(degree, degree);
 	for (unsigned i = 0; i < degree; i++){
@@ -106,16 +82,16 @@ TPoint GetPolynomial(unsigned degree, TMatrix& points) {
 	}
 
 	bPM pm(A.size1());
-	boost::numeric::ublas::lu_factorize(A, pm);
+	bPM::size_type singular = boost::numeric::ublas::lu_factorize(A, pm);
+	if (singular != 0) return false;
 	boost::numeric::ublas::lu_substitute(A, pm, b);
 
-	TPoint polynomial(degree);
 	for (unsigned i = 0; i < degree; i++){
-    if (!(b[i] < std::numeric_limits<double>::max()) || b[i] < -std::numeric_limits<double>::max()){  throw "not a value or inf"; }
+		if (!(b[i] < std::numeric_limits<double>::max()) || b[i] < -std::numeric_limits<double>::max()){  return false; }
 		polynomial[i] = b[i];
 	}
   
-	return polynomial;
+	return true;
 }
 
 /**
@@ -130,13 +106,13 @@ Chooses the best in classification sense polynomial among
 
 @return polynomial as a vector of coefficients starting with the first degree (a0 = 0 always)
 */
-TPoint GetRandomMinPolynomial(TMatrix& points, unsigned numClass1, unsigned degree, unsigned n_polynomials){
-
-	vector<int> usedIndexesX(points.size());
-	vector<int> usedIndexesY(points.size());
+TPoint GetRandomMinPolynomial(TDMatrix points, unsigned numClass1, unsigned numClass2, unsigned degree, unsigned n_polynomials){
+	unsigned n = numClass1 + numClass2;
+	vector<int> usedIndexesX(n);
+	vector<int> usedIndexesY(n);
 	int nx = 0, ny = 0;
 
-	for (unsigned i = 0; i<points.size(); i++){
+	for (unsigned i = 0; i<n; i++){
 		if (points[i][0] != 0){
 			usedIndexesX[nx++] = i;
 			if (points[i][1] != 0)
@@ -144,13 +120,15 @@ TPoint GetRandomMinPolynomial(TMatrix& points, unsigned numClass1, unsigned degr
 		}
 	}
 
-	int numOfCombinations = boost::math::binomial_coefficient<double>(nx - 1, degree - 1) * ny * 0.3; // 1/3 of all combination
+	// 0.3 of all combination
+	int numOfCombinations = boost::math::binomial_coefficient<double>(nx - 1, degree - 1) * ny * 0.3; 
 	int numCandidates = (numOfCombinations > n_polynomials
 		? n_polynomials
 		: numOfCombinations);
 
 	TPoint minPolynomial(degree);
 	double minEmpRisk = 1;
+	TDMatrix sample = new double*[degree];
 	for (int i = 0; i < numCandidates; i++){
 		// generate sample
 		set<int> smp;
@@ -159,108 +137,178 @@ TPoint GetRandomMinPolynomial(TMatrix& points, unsigned numClass1, unsigned degr
 			smp.insert(usedIndexesX[random(nx)]);
 		}
 
-		TMatrix sample(degree);
 		set <int>::const_iterator s = smp.begin();
 		for (unsigned j = 0; j < degree; j++, s++) {
 			sample[j] = points[*s];
 		}
 
 		try{
-			TPoint pol = GetPolynomial(degree, sample);
-			double rsk = GetEmpiricalRisk(pol, points, numClass1);
+			TPoint pol(degree);
+			if(!GetPolynomial(degree, sample, pol))
+				continue;
+			double rsk = GetEmpiricalRisk(pol, points, numClass1, numClass2);
 			if (rsk < minEmpRisk) {
-  			minPolynomial = pol;
-  			minEmpRisk = rsk;        
+  				minPolynomial = pol;
+  				minEmpRisk = rsk;        
 			}
 		}
 		catch (runtime_error &e){ /* singular matrix*/ }
 		catch (...){ /* NA or inf */ }
 	}
+	delete[] sample;
 	return minPolynomial;
 }
 
-#ifndef _MSC_VER
+static int _degree;
+static TDMatrix _points;
+static unsigned _numClass1;
+static unsigned _numClass2;
 
-#include <Rcpp.h> 
-using namespace Rcpp;
+/**
+Calculates the empirical risk for two classes on the basis of given depths
+and approximates it to get continuous derivative
 
-// [[Rcpp::export]]
-double CGetEmpiricalRiskSmoothed(NumericVector& polynomial, NumericMatrix& points, int numClass1, int numClass2){
+@param polynomial : Polynomial as a vector of coefficients starting with the first degree(a0 = 0 always)
+@param _points : nx2 matrix of depths, where each column contains the depths against the corresponding class
+@param _numClass1:  Number of points belonging to the first class
+@param _numClass2:  Number of points belonging to the first class
+@return polynomial as a vector of coefficients starting with the first degree (a0 = 0 always)
+*/
+double GetEmpiricalRiskSmoothed(double polynomial[]){
 	const float smoothingConstant = 100;
-	unsigned degree = polynomial.size();
-
+	
 	double risk = 0;
 	int sign = 1;
-	for (unsigned i = 0; i < numClass1 + numClass2; i++){
-		if (i >= numClass1)
+	for (unsigned i = 0; i < _numClass1 + _numClass2; i++){
+		if (i >= _numClass1)
 			sign = -1;
 
-		double val = points(i, 0);
+		double val = (_points)[i][0];
 		double res = 0;
-		for (unsigned j = 0; j < degree; j++){
-			res += polynomial[j] * std::pow(val, j + 1);
+		for (unsigned j = 0; j < _degree; j++){
+			res += polynomial[j] * std::pow(val, j+1);
 		}
-		risk += 1 / (1 + exp(-smoothingConstant*(points(i, 1) - res)*sign));
+		risk += 1 / (1 + exp(-smoothingConstant*((_points)[i][1] - res)*sign));
 	}
 
-	return risk / (numClass1 + numClass2);
+	return risk / _numClass1 + _numClass2;
 }
 
-TPoint nlm_optimize(TMatrix& points, TPoint& minCandidate, int numClass1, int numClass2){
 
-	NumericVector r_minCandidate(minCandidate.begin(), minCandidate.end());
-	NumericMatrix r_points(points.size(), 2);
-	for (int i = 0; i < points.size(); i++){ r_points(i, 0) = points[i][0]; r_points(i, 1) = points[i][1]; }
+TPoint nlm_optimize(TDMatrix points, TPoint& minCandidate, int numClass1, int numClass2){
+	/* static variables for GetEmpiricalRiskSmoothed */
+	_points = points;
+	_numClass1 = numClass1;
+	_numClass2 = numClass2;
+	_degree = minCandidate.size();
 
-  Environment env("package:ddalpha");
+	double* start = new double[_degree];
+	std::copy(minCandidate.begin(), minCandidate.end(), start);
 
-  Function nlm("nlm"); 
- // Function getRisk = env["CGetEmpiricalRiskSmoothed"];
-  Function optimize = env["nlm_optimize_r"];
+	int icount;
+	int ifault;
+	int kcount;
+	int konvge;
+	int n = _degree;
+	int numres;
+	double reqmin;
+	double *step;
+	double *xmin;
+	double ynewlo;
 
-	NumericVector r_pol = optimize(r_minCandidate, r_points, numClass1, numClass2);
+	step = new double[n];
+	xmin = new double[n];
 
-	return as<TPoint>(r_pol);
+	reqmin = 1.0E-06;
+
+	for (int i = 0; i < n; i++)
+	{
+		// determines the size and shape of the initial simplex.
+		// The relative magnitudes of its elements should reflect the units of the variables.  
+		step[i] = 1.0;
+	}
+
+	konvge = 10;
+	kcount = 500;
+	/*
+	cout << "\n";
+	cout << "  Starting point X:\n";
+	cout << "\n";
+	for (i = 0; i < n; i++)
+	{
+		cout << "  " << start[i] << "";
+	}
+	cout << "\n";
+	
+	ynewlo = GetEmpiricalRiskSmoothed(start);
+
+	cout << "\n";
+	cout << "  F(X) = " << ynewlo << "\n";
+	*/
+	nelmin(GetEmpiricalRiskSmoothed, n, start, xmin, &ynewlo, reqmin, step,
+		konvge, kcount, &icount, &numres, &ifault);
+	/*
+	cout << "\n";
+	cout << "  Return code IFAULT = " << ifault << "\n";
+	cout << "\n";
+	cout << "  Estimate of minimizing value X*:\n";
+	cout << "\n";
+	for (i = 0; i < n; i++)
+	{
+		cout << "  " << setw(14) << xmin[i] << "\n";
+	}
+
+	cout << "\n";
+	cout << "  F(X*) = " << ynewlo << "\n";
+
+	cout << "\n";
+	cout << "  Number of iterations = " << icount << "\n";
+	cout << "  Number of restarts =   " << numres << "\n";
+*/
+	TPoint minpol = TPoint(xmin, xmin + _degree);
+
+	delete[] start;
+	delete[] step;
+	delete[] xmin;
+
+	return minpol;
 }
 
-#endif
-
 /**
 Chooses the best in classification sense polynomial
 
-@param points:       nx2 matrix of points where first column is an absciss,	n = numClass1 + numClass2
+@param points:       nx2 matrix of points where first column is an abscissa, n = numClass1 + numClass2
 @param numClass1:    Number of points belonging to the first class
 @param degree:       Degree of the polynomial
 @param presize:		 if true - run evaluation 5 times
 
 @return polynomial as a vector of coefficients starting with the first degree (a0 = 0 always)
 */
-TPoint GetOptPolynomial(TMatrix& points, unsigned numClass1, unsigned degree, bool presize /*default = FALSE*/){
+TPoint GetOptPolynomial(TDMatrix points, unsigned numClass1, unsigned numClass2, unsigned degree, bool presize /*default = FALSE*/){
 
 	double minError = 100.1;
 	TPoint minPol;
 	
-	for (int i = 0; i < (presize ? 5 : 1); i++){
-		TPoint minCandidate = GetRandomMinPolynomial(points, numClass1, degree, 10 ^ degree);
-
-#ifdef VStudio
-		// no optimization
-		minPol = minCandidate;
-#endif
-#ifndef VStudio
+	for (int i = 0; i < (presize ? 3 : 1); i++){
+		TPoint minCandidate = GetRandomMinPolynomial(points, numClass1, numClass2, degree, 10 ^ degree);
+		double err = GetEmpiricalRisk(minCandidate, points, numClass1, numClass2);
+		if (err < minError){
+			minPol = minCandidate;
+			minError = err;
+		}
 
+//#define DEBUG
 #ifdef DEBUG
 Rcpp::Rcout << "candminPol: ";
-for (int i = 0; i< minCandidate.size(); i++){
+for (int i = 0; i< degree; i++){
   Rcpp::Rcout << minCandidate[i] << " ";
 }
-Rcpp::Rcout <<  " \n";
+Rcpp::Rcout << " ; error = "<< err << " \n";
 #endif
 
-
-		TPoint optPolynomial = nlm_optimize(points, minCandidate, numClass1, points.size() - numClass1);
-		int err = GetEmpiricalRisk(optPolynomial, points, numClass1);
-		if (err < minError){
+		TPoint optPolynomial = nlm_optimize(points, minCandidate, numClass1, numClass2);
+		err = GetEmpiricalRisk(optPolynomial, points, numClass1, numClass2);
+		if (err <= minError){
 			minPol = optPolynomial;
 			minError = err;
 		}
@@ -271,10 +319,7 @@ for (int i = 0; i< minPol.size(); i++){
   Rcpp::Rcout << minPol[i] << " ";
 }
 Rcpp::Rcout << " ; error = "<< minError << " \n";
-#endif
-
-#endif	
-		
+#endif		
 	}  
 
 	return(minPol);
@@ -291,12 +336,13 @@ Calculates classification error of "degree" - degree polynomial using cross - va
 
 @return Number of errors
 */
-int GetCvError(TMatrix& points, unsigned numClass1, unsigned degree, unsigned chunkNumber){
+double GetCvError(TDMatrix points, unsigned numClass1, unsigned numClass2, unsigned degree, unsigned chunkNumber){
 
-	unsigned n = points.size();
+	unsigned n = numClass1 + numClass2;
 	unsigned chunkSize = ceil((double)n / chunkNumber);
 
-	TMatrix learnpoints(n - chunkSize); TMatrix checkpoints(chunkSize);
+	TDMatrix learnpoints = new double*[n - chunkSize+1]; 
+	TDMatrix checkpoints = new double*[chunkSize];
 
 	int chunk = 0;
 	int n1 = 0; // number of Class1 points in checkpoints
@@ -316,8 +362,8 @@ int GetCvError(TMatrix& points, unsigned numClass1, unsigned degree, unsigned ch
 			if (bigch && (chunkNumber)*(chunkSize - 1) + chunk == n){
 				bigch = false;
 				chunkSize--;
-				checkpoints.resize(chunkSize);
-				learnpoints.resize(n - chunkSize);
+				//checkpoints.resize(chunkSize);
+				//learnpoints.resize(n - chunkSize);
 				learnpoints[n - chunkSize - 1] = points[n - 1];
 			}
 
@@ -329,45 +375,51 @@ int GetCvError(TMatrix& points, unsigned numClass1, unsigned degree, unsigned ch
 			}
 		}
 
-		TPoint minPolynomial = GetOptPolynomial(learnpoints, numClass1 - n1, degree, false);
-		double curErr = GetEmpiricalRisk(minPolynomial, checkpoints, n1);
+		TPoint minPolynomial = GetOptPolynomial(learnpoints, numClass1 - n1, numClass2 - chunkSize + n1, degree, false);
+		double curErr = GetEmpiricalRisk(minPolynomial, checkpoints, n1, chunkSize - n1);
 		err += curErr;//  chunkSize;
 	}
 
+	delete[] learnpoints;
+	delete[] checkpoints;
 	return err/n;
 }
 
-TPoint PolynomialLearnCV(TMatrix& input, unsigned numClass1, unsigned int maxDegree, unsigned int chunkNumber, int *degree, int *axis){
-	unsigned numPoints = input.size();
+TPoint PolynomialLearnCV(TDMatrix input, unsigned numClass1, unsigned numClass2, unsigned int maxDegree, unsigned int chunkNumber, int *degree, int *axis){
+	unsigned numPoints = numClass1 + numClass2;
 
 	unsigned polOptDegree = 0;
-	unsigned polOptError = numPoints;
+	double polOptError = numPoints;
 	unsigned polOptAxis = 0;
 
-
-	TMatrix input2(numPoints); // copy
-	for (int i = 0, tmp; i < numPoints; i++){ input2[i] = TPoint(2); input2[i][0] = input[i][1]; input2[i][1] = input[i][0]; } // swap columns
+	TDMatrix input2 = newM(numPoints, 2); // copy
+	for (int i = 0, tmp; i < numPoints; i++){ input2[i][0] = input[i][1]; input2[i][1] = input[i][0]; } // swap columns
 
 	for (int degree = 1; degree <= maxDegree; degree++){
-		double polError = GetCvError(input, numClass1, degree, chunkNumber);
+		double polError = GetCvError(input, numClass1, numClass2, degree, chunkNumber);
+		//cout << degree << " " << polError << "\n";
 		if (polError < polOptError){
 			polOptAxis = 0;
 			polOptDegree = degree;
 			polOptError = polError;
 		}
-		polError = GetCvError(input, numClass1, degree, chunkNumber);
+		polError = GetCvError(input2, numClass1, numClass2, degree, chunkNumber);
+		//cout << degree << " " << polError << "\n";
 		if (polError < polOptError){
 			polOptAxis = 1;
 			polOptDegree = degree;
 			polOptError = polError;
 		}
 	}
+
+	//cout << polOptDegree << " " << polOptError << "\n";
 	TPoint polynomial = polOptAxis == 0
-		? GetOptPolynomial(input, numClass1, polOptDegree, true) 
-		: GetOptPolynomial(input2, numClass1, polOptDegree, true);
+		? GetOptPolynomial(input, numClass1, numClass2, polOptDegree, true)
+		: GetOptPolynomial(input2, numClass1, numClass2, polOptDegree, true);
+
+	deleteM(input2);
 
 	*axis = polOptAxis;
 	*degree = polOptDegree;
-
 	return polynomial;
 }
